<?php
/*
Plugin Name: Readtime Shortcode / Videocounter by EasyToolsWP
Description: A simple shortcode to display estimated read time based on word count, excluding words in links and count YouTube videos.
Version: 1.7
Author: EasyToolsWP.com
*/

// Shortcode function to calculate and display read time
function readtime_shortcode($atts) {
    // Extract attributes
    $atts = shortcode_atts(
        array(
            'youtube' => false,
        ),
        $atts,
        'readtime'
    );

    // Get post content (if viewing a single post/page)
    if (is_singular()) {
        $content = get_post_field('post_content', get_the_ID());

        // Remove all links from the content
        $content_without_links = preg_replace('/<a\s[^>]*>(.*?)<\/a>/i', '', $content);

        // Count words
        $word_count = str_word_count(strip_tags($content_without_links));

        // Calculate read time based on average reading speed (250 words per minute)
        $read_time = ceil($word_count / 250);

        // Ensure at least 1 minute read time if there are words
        if ($word_count > 0 && $read_time < 1) {
            $read_time = 1;
        }

        // Default message
        $message = sprintf(__('Read time: %d minute(s)', 'readtime-shortcode'), $read_time);

        // If youtube attribute is true, count YouTube videos
        if ($atts['youtube']) {
            // Regex to find YouTube iframes, embed links, and direct links
            preg_match_all('/<iframe[^>]*src=["\'].*?youtube\.com\/embed\/([a-zA-Z0-9_-]+)["\'][^>]*><\/iframe>/is', $content, $iframe_matches);
            preg_match_all('/<embed[^>]*src=["\'].*?youtube\.com\/v\/([a-zA-Z0-9_-]+)["\'][^>]*>/is', $content, $embed_matches);
            preg_match_all('/https:\/\/www\.youtube\.com\/watch\?v=([a-zA-Z0-9_-]+)/is', $content, $link_matches);

            // Combine all matches into a single array
            $all_matches = array_merge($iframe_matches[1], $embed_matches[1], $link_matches[1]);

            // Debugging output to check all found video IDs
            echo '<!-- All Found Video IDs: ' . implode(', ', $all_matches) . ' -->';

            // Remove duplicate video IDs
            $unique_video_ids = array_unique($all_matches);

            // Debugging output to check unique video IDs
            echo '<!-- Unique Video IDs: ' . implode(', ', $unique_video_ids) . ' -->';

            // Count total unique YouTube videos
            $total_youtube_videos = count($unique_video_ids);

            // Append YouTube video count to message
            $message .= sprintf(__(' and %d video(s)', 'readtime-shortcode'), $total_youtube_videos);
        }

        return $message;
    }
    return '';
}
add_shortcode('readtime', 'readtime_shortcode');

